<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="工程名称" prop="projectName">
        <el-input
          v-model="queryParams.projectName"
          placeholder="请输入工程名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="主项目" prop="projectInfoId">
        <el-row>
          <el-select v-model="queryParams.projectInfoId" filterable clearable style="width: 100%" placeholder="请选择主项目">
            <el-option
              v-for="item in projectList"
              :key="'pp1' + item.id"
              :label="item.projectName"
              :value="item.id">
            </el-option>
          </el-select>
        </el-row>
      </el-form-item>
      <el-form-item label="项目推进类型" label-width="120px" prop="projectType">
        <el-select v-model="queryParams.projectType" placeholder="请选择项目推进类型" clearable>
          <el-option
            v-for="dict in dict.type.sys_project_type"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item label="状态" prop="status">
        <el-select v-model="queryParams.status" placeholder="请选择状态" clearable>
          <el-option
            v-for="dict in dict.type.sys_project_status"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['code:engineering:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['code:engineering:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['code:engineering:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['code:engineering:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="engineeringList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="工程名称" align="center" prop="projectName" />
      <el-table-column label="主项目名称" align="center" prop="projectInfoName" />
      <el-table-column label="项目推进类型" align="center" prop="projectType">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_project_type" :value="scope.row.projectType"/>
        </template>
      </el-table-column>
      <el-table-column label="投资额" align="center" prop="investmentAmount" />
      <el-table-column label="开工状态" align="center" prop="status">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.sys_project_status" :value="scope.row.status"/>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['code:engineering:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['code:engineering:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.currentPage"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改工程库对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="800px" :close-on-click-modal="false" :destroy-on-close="true" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="工程名称" prop="projectName">
          <el-input v-model="form.projectName" placeholder="请输入工程名称" />
        </el-form-item>
        <el-form-item label="主项目" prop="projectInfoId">
          <el-row>
            <el-select v-model="form.projectInfoId" filterable style="width: 100%" placeholder="请选择主项目">
              <el-option
                v-for="item in projectList"
                :key="'pp' + item.id"
                :label="item.projectName"
                :value="item.id">
              </el-option>
            </el-select>
          </el-row>
        </el-form-item>
        <el-row :gutter="20">
          <el-col :span="12">
            <el-form-item label="投资额(万)" prop="investmentAmount">
              <el-input v-model="form.investmentAmount" type="number" placeholder="请输入投资额(万元)" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="项目推进类型" prop="projectType" label-width="100px">
              <el-select v-model="form.projectType" style="width: 100%" placeholder="请选择项目推进类型">
                <el-option
                  v-for="dict in dict.type.sys_project_type"
                  :key="dict.value"
                  :label="dict.label"
                  :value="dict.value"
                ></el-option>
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-form-item label="开工状态" prop="status">
          <el-select v-model="form.status" placeholder="请选择开工状态">
            <el-option
              v-for="dict in dict.type.sys_project_status"
              :key="'1111' + dict.value"
              :value="dict.value"
              :label="dict.label"
            ></el-option>
          </el-select>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { getProjectEngineerings, getProjectEngineeringById, deleteProjectEngineeringByIds, editProjectEngineering, addProjectEngineering } from "@/api/projectEngineering/projectEngineering";
import {list} from "@/api/projectEngineering/projectInfo";

export default {
  name: "Engineering",
  dicts: ['sys_project_type', 'sys_project_status'],
  data() {
    return {
      projectList: [],  // 主项目列表
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 工程库表格数据
      engineeringList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        currentPage: 1,
        pageSize: 10,
        projectInfoId: null,
        projectName: null,
        projectType: null,
        status: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        projectName: [{required: true, message: '请输入工程名称', trigger: 'blur'}],
        projectInfoId: [{required: true, message: '请选择主项目', trigger: 'change'}],
        investmentAmount: [{required: true, message: '请输入投资额', trigger: 'change'}],
        projectType: [{required: true, message: '请选择流程推进类型', trigger: 'change'}],
        status: [{required: true, message: '请选择开工状态', trigger: 'change'}],
      }
    };
  },
  created() {
    this.getList();
    this.getProjectList();
  },
  methods: {
    getProjectList() {
      list().then(res => {
        this.projectList = res.data
      })
    },
    /** 查询工程库列表 */
    getList() {
      this.loading = true;
      getProjectEngineerings(this.queryParams).then(res => {
        this.engineeringList = res.data;
        this.total = res.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        projectInfoId: null,
        projectName: null,
        projectType: null,
        investmentAmount: null,
        status: null,
        gmtCreate: null,
        gmtUpdate: null,
        deleted: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加工程";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getProjectEngineeringById(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改工程";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            editProjectEngineering(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addProjectEngineering(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除工程库编号为"' + ids + '"的数据项？').then(function() {
        return deleteProjectEngineeringByIds(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('code/engineering/export', {
        ...this.queryParams
      }, `engineering_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
